@@ -43,7 +43,7 @@ def parseaddr(val):
 
 
 def process(msg):
-    ctype = msg.gettype()
+    ctype = msg.gettype() or ''
     param = msg.getparam('report-type') or ''
     if string.lower(ctype) <> 'multipart/report' or \
        string.lower(param) <> 'delivery-status':
@@ -60,6 +60,11 @@ def process(msg):
         except multifile.Error:
             # the message *looked* like a DSN, but it really wasn't :(
             return None
+        except TypeError:
+            # This message has serious problems, pass it on.  Seen in the
+            # wild: it is a MIME document with no boundary parameter in its
+            # Content-Type: header.
+            return None
         if not more:
             # we didn't find it
             return None
