@@ -207,7 +207,7 @@ def PrintPostRequest(mlist, id, info, total, count, form):
             return
         raise
     t = Table(cellspacing=0, cellpadding=0, width='100%')
-    t.AddRow([Bold('From:'), sender])
+    t.AddRow([Bold('From:'), cgi.escape(sender)])
     row, col = t.GetCurrentRowIndex(), t.GetCurrentCellIndex()
     t.AddCellInfo(row, col-1, align='right')
     t.AddRow([Bold('Subject:'), cgi.escape(subject)])
@@ -247,12 +247,14 @@ def PrintPostRequest(mlist, id, info, total, count, form):
     row, col = t.GetCurrentRowIndex(), t.GetCurrentCellIndex()
     t.AddCellInfo(row, col-1, align='right')
     t.AddRow([Bold('Message Headers:'),
-              TextArea('headers-%d' % id, string.join(msg.headers, ''),
+              TextArea('headers-%d' % id,
+                       cgi.escape(string.join(msg.headers, '')),
                        rows=10, cols=80)])
     row, col = t.GetCurrentRowIndex(), t.GetCurrentCellIndex()
     t.AddCellInfo(row, col-1, align='right')
     t.AddRow([Bold('Message Excerpt:'),
-              TextArea('fulltext-%d' % id, text, rows=10, cols=80)])
+              TextArea('fulltext-%d' % id, cgi.escape(text),
+                       rows=10, cols=80)])
     t.AddCellInfo(row+1, col-1, align='right')
     form.AddItem(t)
     form.AddItem('<p>')
